==> Cosmos.uv7.20.tar.gz: UserHook/DisParaRescue/Smash/mergeSkel.f <==
      implicit none
c  
c
c     Merge two  smashed skeletons
c
c    smashed skeleton data format
c  
c      skeleton001
c        cumnum, num, ir, Zfirst
c        Np
c        observed ptcles 1
c        observed ptcles 2
c
c        observed ptcles Np
c        nlowp  
c        track-1
c        track-2
c        ... 
c
c        track-nlowp
c     other skeleton file( skeleton002,...)
c        cumnum, num, ir, Zfirst
c        0
c        nlowp  
c        track-1
c        track-2
c        ...
c        track-nlowp
c        ....
c
#include "Ztrack.h"
#include "Zearth.h"
      include "../../SkelFlesh/Zprivate.h"
      include "Zprivate2.h"

      record /track/ ctrack
      integer icon
      integer klena
      integer i, nlow, nlow2, cumnum, num, ir(2)
      record /ob/ ooo
      record /track/ Zfirst
      character*128 file1, file2, file3
      character*128  input, file(2)
      logical inp1, inp2
      integer  nr, Np2

      file3="tempskel"
      read( *, '(a)' ) input
      call ksplit(input, 128, 2, file, nr)
      file1 = file(1)
      file2 = file(2)
c///////
c      write(*,*) ' file1=',file1(1:klena(file1))
c      write(*,*) ' file2=',file2(1:klena(file2))
c//////
c        binary open
      call copenfw2(11, file1, 2, icon)
      if(icon .ne. 1) then
         write(msg,*) file1(1:klena(file1)),
     *    ' could not be opened properly'
         call cerrorMsg(msg, 0)
      endif
      call copenfw2(12, file2, 2, icon)
      if(icon .ne. 1) then
         write(msg,*) file2(1:klena(file2)),
     *    ' could not be opened properly'
         call cerrorMsg(msg, 0)
      endif

      call copenfw2(13, file3, 2, icon)

      inp1=.true.
      inp2=.true.
      do while ( inp1 .or. inp2 )
         if(inp1) then
            read(11, end=10) cumnum, num, ir, Zfirst
            read(11) Np
            goto 5
 10         continue
            inp1 = .false.
            Np = 0
         else
            Np = 0
         endif
 5       continue
         if(inp2) then
            read(12, end=20) cumnum, num, ir, Zfirst
            read(12) Np2
            goto 15
 20         continue
            inp2 = .false.
            Np2=0
         else
            Np2=0
         endif
 15      continue 

         if(inp1 .or. inp2) then 
            write(13)  cumnum, num, ir, Zfirst
            write(13) Np + Np2
            if(Np+Np2 .gt. Maxob) then
               call cerrorMsg(
     *              'Observed ptcls is too large; enlarge Maxob', 0)
            endif
            do i = 1, Np
               read(11) ooo
               write(13) ooo
            enddo
            do i = 1, Np2
               read(12) ooo
               write(13) ooo
            enddo
            if(inp1) then
               read(11) nlow
            else
               nlow = 0
            endif
            if(inp2) then
               read(12) nlow2
            else
               nlow2 = 0
            endif
            write(13) nlow + nlow2
            do i = 1, nlow
               read(11) ctrack
               write(13) ctrack
            enddo
            do i = 1, nlow2
               read(12) ctrack
               write(13) ctrack
            enddo
         endif
      enddo
      end

==> Cosmos.uv7.29.tar.gz: UserHook/DisParaRescue/Smash/mergeSkel.f <==
      implicit none
c  
c
c     Merge two  smashed skeletons
c
c    smashed skeleton data format
c  
c      skeleton001
c        cumnum, num, ir, Zfirst
c        Np
c        observed ptcles 1
c        observed ptcles 2
c
c        observed ptcles Np
c        nlowp  
c        track-1
c        track-2
c        ... 
c
c        track-nlowp
c     other skeleton file( skeleton002,...)
c        cumnum, num, ir, Zfirst
c        0
c        nlowp  
c        track-1
c        track-2
c        ...
c        track-nlowp
c        ....
c
#include "Ztrack.h"
#include "Zearth.h"
#include "../../SkelFlesh/Zprivate.h"
#include "../../DisPara/Smash/Zprivate2.h"

      record /track/ ctrack
      integer icon
      integer klena
      integer i, nlow, nlow2, cumnum, num, ir(2)
      record /ob/ ooo
      record /track/ Zfirst
      character*128 file1, file2, file3
      character*128  input, file(2)
      logical inp1, inp2
      integer  nr, Np2

      file3="tempskel"
      read( *, '(a)' ) input
      call ksplit(input, 128, 2, file, nr)
      file1 = file(1)
      file2 = file(2)
c///////
c      write(*,*) ' file1=',file1(1:klena(file1))
c      write(*,*) ' file2=',file2(1:klena(file2))
c//////
c        binary open
      call copenfw2(11, file1, 2, icon)
      if(icon .ne. 1) then
         write(msg,*) file1(1:klena(file1)),
     *    ' could not be opened properly'
         call cerrorMsg(msg, 0)
      endif
      call copenfw2(12, file2, 2, icon)
      if(icon .ne. 1) then
         write(msg,*) file2(1:klena(file2)),
     *    ' could not be opened properly'
         call cerrorMsg(msg, 0)
      endif

      call copenfw2(13, file3, 2, icon)

      inp1=.true.
      inp2=.true.
      do while ( inp1 .or. inp2 )
         if(inp1) then
            read(11, end=10) cumnum, num, ir, Zfirst
            read(11) Np
            goto 5
 10         continue
            inp1 = .false.
            Np = 0
         else
            Np = 0
         endif
 5       continue
         if(inp2) then
            read(12, end=20) cumnum, num, ir, Zfirst
            read(12) Np2
            goto 15
 20         continue
            inp2 = .false.
            Np2=0
         else
            Np2=0
         endif
 15      continue 

         if(inp1 .or. inp2) then 
            write(13)  cumnum, num, ir, Zfirst
            write(13) Np + Np2
            if(Np+Np2 .gt. Maxob) then
               call cerrorMsg(
     *              'Observed ptcls is too large; enlarge Maxob', 0)
            endif
            do i = 1, Np
               read(11) ooo
               write(13) ooo
            enddo
            do i = 1, Np2
               read(12) ooo
               write(13) ooo
            enddo
            if(inp1) then
               read(11) nlow
            else
               nlow = 0
            endif
            if(inp2) then
               read(12) nlow2
            else
               nlow2 = 0
            endif
            write(13) nlow + nlow2
            do i = 1, nlow
               read(11) ctrack
               write(13) ctrack
            enddo
            do i = 1, nlow2
               read(12) ctrack
               write(13) ctrack
            enddo
         endif
      enddo
      end
